import { ChartAnnotation, ChartDimension, ChartMeasure, ChartMeasureRoleType, ChartOrient, EntityType, PropertyHierarchy, PropertyMeasure } from '@metad/ocap-core';
import { AxisEnum, EChartsContext, EChartsOptions } from '../types';
/**
 * 设置轴方向布局
 *
 * @param orient ChartOrient
 * @return [categoryAxis, valueAxis]
 */
export declare function axisOrient(orient: ChartOrient): [AxisEnum, AxisEnum];
/**
 * Calc Axis and DataZoom for category dimension
 *
 * @param categoryType Axis Type [ECharts xAxis.type](https://echarts.apache.org/en/option.html#xAxis.type)
 * @param items
 * @param dimension
 * @param categoryProperty
 * @param chartOptions
 * @returns
 */
export declare function getCategoryAxis(context: EChartsContext, items: Array<unknown>, dimension: ChartDimension, categoryProperty: PropertyHierarchy, chartOptions: EChartsOptions, measure: string, categoryType?: string): any;
/**
 * 从度量中计算出值轴配置
 *
 * @param chartAnnotation
 * @param entityType
 * @param chartOptions
 * @param locale
 * @returns
 */
export declare function getValueAxis(chartAnnotation: ChartAnnotation, entityType: EntityType, chartOptions: EChartsOptions, locale?: string): any;
/**
 * Find measure by measure role or index
 *
 * @param chartAnnotation
 * @param role
 * @param index
 * @returns
 */
export declare function getMeasureAxis(chartAnnotation: ChartAnnotation, role: ChartMeasureRoleType, index: number): ChartMeasure;
/**
 *
 * @param category
 * @param items
 * @param property 暂时只支持一个 dimension
 */
export declare function getCategoryAxisPointer(context: EChartsContext, items: Array<unknown>, category: ChartDimension, measure: string): any;
export declare function valueAxisLabelFormatter(measure: ChartMeasure, property: PropertyMeasure, value: any, locale?: string): string;
